@@ -157,7 +157,8 @@ class SliceTest(g.unittest.TestCase):
         mesh = g.trimesh.creation.box()
 
         # Cut corner off of box and make sure the bounds and number of faces is correct
-        # Tests new triangles, but not new quads or triangles contained entirely
+        # Tests new triangles, but not new quads or triangles contained
+        # entirely
         plane_origin = mesh.bounds[1] - 0.05
         plane_normal = mesh.bounds[1]
 
@@ -233,12 +234,34 @@ class SliceTest(g.unittest.TestCase):
                    + 0.01 * g.trimesh.unitize([1, 0, 2])]
         normals = [g.trimesh.unitize([1, 1, 1]), g.trimesh.unitize([1, 2, 3])]
 
+    def test_slice_onplane(self):
+        m = g.get_mesh('featuretype.STL')
+        # on a plane with a lot of coplanar triangles
+        n = g.np.array([0, 0, 1.0])
+        o = g.np.array([0, 0, 1.0])
+
+        # slice the mesh in two pieces
+        a = m.slice_plane(plane_origin=o,
+                          plane_normal=-n,
+                          cap=True)
+        b = m.slice_plane(plane_origin=o,
+                          plane_normal=n,
+                          cap=True)
+
+        # both slices should be watertiight
+        assert a.is_watertight
+        assert b.is_watertight
+        # volume should match original
+        assert g.np.isclose(m.volume, a.volume + b.volume)
+
     def test_slice_submesh(self):
         bunny = g.get_mesh('bunny.ply')
 
         # Find the faces on the body.
-        neck_plane_origin = g.np.array([-0.0441905, 0.124347, 0.0235287])
-        neck_plane_normal = g.np.array([0.35534835, -0.93424839, -0.03012456])
+        neck_plane_origin = g.np.array(
+            [-0.0441905, 0.124347, 0.0235287])
+        neck_plane_normal = g.np.array(
+            [0.35534835, -0.93424839, -0.03012456])
 
         dots = g.np.einsum('i,ij->j', neck_plane_normal,
                            (bunny.vertices - neck_plane_origin).T)
@@ -317,8 +340,8 @@ class SliceTest(g.unittest.TestCase):
         if not g.has_earcut:
             return
 
+        from trimesh.transformations import random_rotation_matrix
         for i in range(100):
-            from trimesh.transformations import random_rotation_matrix
             box1 = g.trimesh.primitives.Box(
                 extents=[10, 20, 30],
                 transform=random_rotation_matrix())
@@ -339,7 +362,8 @@ class SliceTest(g.unittest.TestCase):
         mesh = g.trimesh.creation.box()
 
         # Cut corner off of box and make sure the bounds and number of faces is correct
-        # Tests new triangles, but not new quads or triangles contained entirely
+        # Tests new triangles, but not new quads or triangles contained
+        # entirely
         plane_origin = mesh.bounds[1] - 0.05
         plane_normal = mesh.bounds[1]
 
@@ -349,7 +373,9 @@ class SliceTest(g.unittest.TestCase):
                                          cap=True)
 
         assert len(sliced_capped.faces) == 8
-        assert g.np.isclose(sliced_capped.bounds[0], mesh.bounds[1] - 0.15).all()
+        assert g.np.isclose(
+            sliced_capped.bounds[0],
+            mesh.bounds[1] - 0.15).all()
         assert g.np.isclose(sliced_capped.bounds[1], mesh.bounds[1]).all()
         assert sliced_capped.is_watertight
 
