@@ -361,13 +361,13 @@ class Cache(object):
           If set will make all numpy arrays read-only
         """
         self._id_function = id_function
-        # force stored numpy arrays to have flags.writable=False
+        # for stored numpy arrays set `flags.writable = False`
         self.force_immutable = bool(force_immutable)
         # call the id function for initial value
         self.id_current = self._id_function()
         # a counter for locks
         self._lock = 0
-        # actuSal store for data
+        # actual store for data
         self.cache = {}
 
     def delete(self, key):
@@ -471,7 +471,8 @@ class Cache(object):
         # dumpy cache if ID function has changed
         self.verify()
         # make numpy arrays read-only if asked to
-        if self.force_immutable and hasattr(value, 'flags') and len(value.shape) > 0:
+        if self.force_immutable and hasattr(
+                value, 'flags') and len(value.shape) > 0:
             value.flags.writeable = False
         # assign data to dict
         self.cache[key] = value
@@ -497,7 +498,9 @@ class Cache(object):
 class DiskCache(object):
     """
     Store results of expensive operations on disk
-    with an option to expire the results.
+    with an option to expire the results. This is used
+    to cache the multi-gigabyte test corpuses in
+    `tests/corpus.py`
     """
 
     def __init__(self, path, expire_days=30):
