@@ -1,5 +1,6 @@
 import numpy as np
 import collections
+import uuid
 
 from . import cameras
 from . import lighting
@@ -7,6 +8,7 @@ from . import lighting
 from .. import util
 from .. import units
 from .. import convex
+from .. import inertia
 from .. import caching
 from .. import grouping
 from .. import transformations
@@ -92,8 +94,11 @@ class Scene(Geometry3D):
         """
         base = self.graph.base_frame
         for child in self.graph.transforms.children[base]:
-            combined = np.dot(self.graph[child][0], transform)
-            self.graph.update(child, matrix=combined)
+            combined = np.dot(transform, self.graph[child][0])
+            self.graph.update(frame_from=base,
+                              frame_to=child,
+                              matrix=combined)
+        return self
 
     def add_geometry(self,
                      geometry,
@@ -154,7 +159,7 @@ class Scene(Geometry3D):
             return
 
         if not hasattr(geometry, 'vertices'):
-            util.log.warning('unknown type ({}) added to scene!'.format(
+            util.log.debug('unknown type ({}) added to scene!'.format(
                 type(geometry).__name__))
             return
 
@@ -241,10 +246,10 @@ class Scene(Geometry3D):
         # avoid accessing attribute in tight loop
         geometry = self.geometry
         # start with the last modified time of the scene graph
-        hashable = [hex(hash(self.graph))]
+        hashable = [hex(self.graph.transforms.__hash__())]
         # take the re-hex string of the hash
         hashable.extend(hex(geometry[k].__hash__()) for k in
-                        sorted(geometry.keys()))
+                        geometry.keys())
         return caching.hash_fast(
             ''.join(hashable).encode('utf-8'))
 
@@ -385,6 +390,68 @@ class Scene(Geometry3D):
         centroid = np.mean(self.bounds, axis=0)
         return centroid
 
+    @caching.cache_decorator
+    def center_mass(self):
+        """
+        Find the center of mass for every instance in the scene.
+
+        Returns
+        ------------
+        center_mass : (3,) float
+          The center of mass of the scene
+        """
+        # get the center of mass and volume for each geometry
+        center_mass = {k: m.center_mass for k, m in self.geometry.items()
+                       if hasattr(m, 'center_mass')}
+        mass = {k: m.mass for k, m in self.geometry.items()
+                if hasattr(m, 'mass')}
+
+        # get the geometry name and transform for each instance
+        graph = self.graph
+        instance = [graph[n] for n in graph.nodes_geometry]
+
+        # get the transformed center of mass for each instance
+        transformed = np.array(
+            [np.dot(mat, np.append(center_mass[g], 1))[:3]
+             for mat, g in instance
+             if g in center_mass], dtype=np.float64)
+        # weight the center of mass locations by volume
+        weights = np.array(
+            [mass[g] for _, g in instance], dtype=np.float64)
+        weights /= weights.sum()
+        return (transformed * weights.reshape((-1, 1))).sum(axis=0)
+
+    @caching.cache_decorator
+    def moment_inertia(self):
+        """
+        Return the moment of inertia of the current scene with
+        respect to the center of mass of the current scene.
+
+        Returns
+        ------------
+        inertia : (3, 3) float
+          Inertia with respect to cartesian axis at `scene.center_mass`
+        """
+        return inertia.scene_inertia(
+            scene=self,
+            transform=transformations.translation_matrix(self.center_mass))
+
+    def moment_inertia_frame(self, transform):
+        """
+        Return the moment of inertia of the current scene relative
+        to a transform from the base frame.
+
+        Parameters
+        transform : (4, 4) float
+          Homogenous transformation matrix.
+
+        Returns
+        -------------
+        inertia : (3, 3) float
+          Inertia tensor at requested frame.
+        """
+        return inertia.scene_inertia(scene=self, transform=transform)
+
     @caching.cache_decorator
     def area(self):
         """
@@ -403,6 +470,24 @@ class Scene(Geometry3D):
         return sum((areas.get(self.graph[n][1], 0.0) for n in
                     self.graph.nodes_geometry), 0.0)
 
+    @caching.cache_decorator
+    def volume(self):
+        """
+        What is the summed volume of every geometry which
+        has volume
+
+        Returns
+        ------------
+        volume : float
+          Summed area of every instanced geometry
+        """
+        # get the area of every geometry that has a volume attribute
+        volume = {n: g.volume for n, g in self.geometry.items()
+                  if hasattr(g, 'area')}
+        # sum the area including instancing
+        return sum((volume.get(self.graph[n][1], 0.0) for n in
+                    self.graph.nodes_geometry), 0.0)
+
     @caching.cache_decorator
     def triangles(self):
         """
@@ -752,7 +837,9 @@ class Scene(Geometry3D):
             current = self.geometry[geometry_name].copy()
             # move the geometry vertices into the requested frame
             current.apply_transform(transform)
-            current.metadata['name'] = node_name
+            current.metadata['name'] = geometry_name
+            current.metadata['node'] = node_name
+
             # save to our list of meshes
             result.append(current)
 
@@ -956,7 +1043,6 @@ class Scene(Geometry3D):
 
         for node_name in self.graph.nodes_geometry:
             transform, geometry_name = self.graph[node_name]
-
             centroid = self.geometry[geometry_name].centroid
             # transform centroid into nodes location
             centroid = np.dot(transform,
@@ -971,8 +1057,10 @@ class Scene(Geometry3D):
             else:
                 raise ValueError('explode vector wrong shape!')
 
-            transform[:3, 3] += offset
-            self.graph[node_name] = transform
+            # original transform is read-only
+            T_new = transform.copy()
+            T_new[:3, 3] += offset
+            self.graph[node_name] = T_new
 
     def scaled(self, scale):
         """
@@ -981,7 +1069,7 @@ class Scene(Geometry3D):
 
         Parameters
         -----------
-        scale : float
+        scale : float or (3,) float
           Factor to scale meshes and transforms
 
         Returns
@@ -989,52 +1077,117 @@ class Scene(Geometry3D):
         scaled : trimesh.Scene
           A copy of the current scene but scaled
         """
-        scale = float(scale)
-        # matrix for 2D scaling
-        scale_2D = np.eye(3) * scale
-        # matrix for 3D scaling
-        scale_3D = np.eye(4) * scale
+        # convert 2D geometries to 3D for 3D scaling factors
+        scale_is_3D = isinstance(
+            scale, (list, tuple, np.ndarray)) and len(scale) == 3
 
-        # preallocate transforms and geometries
-        nodes = np.array(self.graph.nodes_geometry)
-        transforms = np.zeros((len(nodes), 4, 4))
-        geometries = [None] * len(nodes)
-
-        # collect list of transforms
-        for i, node in enumerate(nodes):
-            transforms[i], geometries[i] = self.graph[node]
+        if scale_is_3D and np.all(np.asarray(scale) == scale[0]):
+            # scale is uniform
+            scale = float(scale[0])
+            scale_is_3D = False
+        elif not scale_is_3D:
+            scale = float(scale)
 
         # result is a copy
         result = self.copy()
-        # remove all existing transforms
-        result.graph.clear()
 
-        for group in grouping.group(geometries):
-            # hashable reference to self.geometry
-            geometry = geometries[group[0]]
-            # original transform from world to geometry
-            original = transforms[group[0]]
-            # transform for geometry
-            new_geom = np.dot(scale_3D, original)
+        if scale_is_3D:
+            # Copy all geometries that appear multiple times in the scene,
+            # such that no two nodes share the same geometry.
+            # This is required since the non-uniform scaling will most likely
+            # affect the same geometry in different poses differently.
+            # Note, that this is not needed in the case of uniform scaling.
+            for geom_name in result.graph.geometry_nodes:
+                nodes_with_geom = result.graph.geometry_nodes[geom_name]
+                if len(nodes_with_geom) > 1:
+                    geom = result.geometry[geom_name]
+                    for n in nodes_with_geom:
+                        p = result.graph.transforms.parents[n]
+                        result.add_geometry(
+                            geometry=geom.copy(),
+                            geom_name=geom_name,
+                            node_name=n,
+                            parent_node_name=p,
+                            transform=result.graph.transforms.edge_data[(
+                                p, n)].get('matrix', None),
+                            extras=result.graph.transforms.edge_data[(
+                                p, n)].get('extras', None))
+                    result.delete_geometry(geom_name)
 
-            if result.geometry[geometry].vertices.shape[1] == 2:
-                # if our scene is 2D only scale in 2D
-                result.geometry[geometry].apply_transform(scale_2D)
-            else:
-                # otherwise apply the full transform
-                result.geometry[geometry].apply_transform(new_geom)
+            # Convert all 2D paths to 3D paths
+            for geom_name in result.geometry:
+                if result.geometry[geom_name].vertices.shape[1] == 2:
+                    result.geometry[geom_name] = result.geometry[geom_name].to_3D()
 
-            for node, T in zip(nodes[group],
-                               transforms[group]):
-                # generate the new transforms
-                transform = util.multi_dot(
-                    [scale_3D, T, np.linalg.inv(new_geom)])
-                # apply scale to translation
-                transform[:3, 3] *= scale
-                # update scene with new transforms
-                result.graph.update(frame_to=node,
-                                    matrix=transform,
-                                    geometry=geometry)
+            # Scale all geometries by un-doing their local rotations first
+            for key in result.graph.nodes_geometry:
+                T, geom_name = result.graph.get(key)
+                # transform from graph should be read-only
+                T = T.copy()
+                T[:3, 3] = 0.0
+
+                # Get geometry transform w.r.t. base frame
+                result.geometry[geom_name].apply_transform(T).apply_scale(
+                    scale).apply_transform(np.linalg.inv(T))
+
+            # Scale all transformations in the scene graph
+            edge_data = result.graph.transforms.edge_data
+            for uv in edge_data:
+                if 'matrix' in edge_data[uv]:
+                    props = edge_data[uv]
+                    T = edge_data[uv]['matrix'].copy()
+                    T[:3, 3] *= scale
+                    props['matrix'] = T
+                    result.graph.update(
+                        frame_from=uv[0], frame_to=uv[1], **props)
+            # Clear cache
+            result.graph.transforms._cache = {}
+            result.graph.transforms._modified = str(uuid.uuid4())
+            result.graph._cache.clear()
+        else:
+            # matrix for 2D scaling
+            scale_2D = np.eye(3) * scale
+            # matrix for 3D scaling
+            scale_3D = np.eye(4) * scale
+
+            # preallocate transforms and geometries
+            nodes = np.array(self.graph.nodes_geometry)
+            transforms = np.zeros((len(nodes), 4, 4))
+            geometries = [None] * len(nodes)
+
+            # collect list of transforms
+            for i, node in enumerate(nodes):
+                transforms[i], geometries[i] = self.graph[node]
+
+            # remove all existing transforms
+            result.graph.clear()
+
+            for group in grouping.group(geometries):
+                # hashable reference to self.geometry
+                geometry = geometries[group[0]]
+                # original transform from world to geometry
+                original = transforms[group[0]]
+                # transform for geometry
+                new_geom = np.dot(scale_3D, original)
+
+                if result.geometry[geometry].vertices.shape[1] == 2:
+                    # if our scene is 2D only scale in 2D
+                    result.geometry[geometry].apply_transform(scale_2D)
+                else:
+                    # otherwise apply the full transform
+                    result.geometry[geometry].apply_transform(new_geom)
+
+                for node, T in zip(nodes[group],
+                                   transforms[group]):
+                    # generate the new transforms
+                    transform = util.multi_dot(
+                        [scale_3D, T, np.linalg.inv(new_geom)])
+                    # apply scale to translation
+                    transform[:3, 3] *= scale
+                    # update scene with new transforms
+                    result.graph.update(frame_to=node,
+                                        matrix=transform,
+                                        geometry=geometry)
         return result
 
     def copy(self):
